#!/bin/bash
#

# build_xerces_c.sh

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> <e14|e15> <debug|prof> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
    if [ -z ${SSIBUILDSHIMS_DIR} ]
    then
       echo "ERROR: failed to setup ssibuildshims ${ssibuildshims_version}"
       exit 1
    fi
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
basequal=${2}
extraqual=${3}
maketar=${4}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=xerces_c
origpkgver=v3_2_0
pkgver=${origpkgver}
ssibuildshims_version=v1_04_02
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtarname=xerces-c-${pkgdotver}

get_this_dir

get_ssibuildshims

source define_basics --

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
   exit 0
fi

echo "building ${package} for ${OS}-${plat}-${qualdir} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

if [ "${extraqual}" = "debug" ]
then
    cxxflg="-g -O0"
elif [ "${extraqual}" = "prof" ]
then
    cxxflg="-O3 -g -DNDEBUG -fno-omit-frame-pointer"
fi
cflg=${cxxflg}

if [[ "${basequal}" == e1[0245] ]]
then
  cxxflg="${cxxflg} -std=c++14 -Wno-deprecated-declarations"
else
  ssi_die "ERROR: unrecognized qualifier ${basequal}"
fi

mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi
mkdir -p ${sourcedir}
if [ ! -d ${sourcedir} ]
then
   echo "ERROR: failed to create ${sourcedir}"
   exit 1
fi

# declare now so we can setup
# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

setup -B ${package} ${pkgver} -q ${fullqual} -z ${fakedb}:${product_dir}:${PRODUCTS} || ssi_die "ERROR: fake setup failed"

set -x

cd ${sourcedir}
tar xf ${tardir}/${pkgtarname}.tar.gz

cd ${blddir}
CXXFLAGS="${cxxflg}" CFLAGS="${cflg}" ${sourcedir}/${pkgtarname}/configure --prefix=${XERCESCROOT} ${extra_command} --without-icu || \
 ssi_die "ERROR: configure failed."
ncore=`${SSIBUILDSHIMS_DIR}/bin/ncores`
make -j ${ncore} || ssi_die "ERROR: make failed."
(( ${SKIP_TESTS:-0} )) || make check || ssi_die "ERROR: make check failed."
make install || ssi_die "ERROR: make install failed."

set +x

if [ ! -d ${XERCESCROOT}/lib ]
then
   echo "ERROR: failed to create ${XERCESCROOT}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${fullqual} || \
  ssi_die "failed to declare ${package} ${pkgver}"

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -q ${fullqual} -z ${product_dir}:${PRODUCTS}
echo "xerces_c is installed at ${XERCESCROOT}"

# fixing pkgconfig file
mv ${XERCESCROOT}/lib/pkgconfig/xerces-c.pc ${XERCESCROOT}/lib/pkgconfig/xerces-c.pc.bak
cat ${XERCESCROOT}/lib/pkgconfig/xerces-c.pc.bak | sed "s%${XERCESCROOT}%\${pcfiledir}/../..%g" > ${XERCESCROOT}/lib/pkgconfig/xerces-c.pc

# remove libtool files since they contain hardwired paths
rm -vf ${XERCESCROOT}/lib/*.la

# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
fi

exit 0
